from abc import ABC

from media_platform.lang.serialization import Serializable


class StreamErrorInfo(Serializable, ABC):
    pass
